//Wolf4SDL\DC
//dc_main.cpp
//2009 - Cyle Terry

#if defined(_arch_dreamcast)

//TODO: Use Port A Only

#include <string.h>
#include "../wl_def.h"
#include "dc/video.h"
#include "kos/dbglog.h"
#include "kos/fs.h"
#include "zlib/zlib.h"

void DC_CheckArguments() {
    FILE *fp;
    char *buf;
    char *result = NULL;

    bool  sampleRateGiven = false;
    bool  audioBufferGiven = false;
    int   length = 0;

    fp = fopen("/cd/data/wolf4sdldc_cmp/args.txt", "r");
    if (!fp)
        return;
    fseek(fp, 0, SEEK_END);
    length = ftell (fp);
    fseek(fp, 0, SEEK_SET);
    buf = (char *)malloc(length + 2);
    fread(buf, 1, length, fp);
    buf[length] = 0;
    fclose(fp);
    result = strtok(buf, " ");

    while (result != NULL) {
#ifndef SPEAR
        if (!strcmp(result, "--goobers"))
#else
        if (!strcmp(result, "--debugmode"))
#endif
            param_debugmode = true;
        else if (!strcmp(result, "--baby"))
            param_difficulty = 0;
        else if (!strcmp(result, "--easy"))
            param_difficulty = 1;
        else if (!strcmp(result, "--normal"))
            param_difficulty = 2;
        else if (!strcmp(result, "--hard"))
            param_difficulty = 3;
        else if (!strcmp(result, "--nowait"))
            param_nowait = true;
        else if (!strcmp(result, "--tedlevel")) {
            result = strtok(NULL, " ");
            param_tedlevel = atoi(result);
        } else if (!strcmp(result, "--res")) {
            result = strtok(NULL, " ");
            screenWidth = atoi(result);
            result = strtok(NULL, " ");
            screenHeight = atoi(result);
            if ( screenWidth % 320 && screenHeight % 200) {
                dbglog(DBG_DEBUG, "Screen height\\width must be a multiple of 320x200\n");
                dbglog(DBG_DEBUG, "Defaulting to 320x200\n");
                screenWidth = 320;
                screenHeight = 200;
            }
        } else if (!strcmp(result, "--resf")) {
            result = strtok(NULL, " ");
            screenWidth = atoi(result);
            result = strtok(NULL, " ");
            screenHeight = atoi(result);
            if (screenWidth < 320 && screenHeight < 200) {
                dbglog(DBG_DEBUG, "Screen height\\width must be at least 320x200\n");
                dbglog(DBG_DEBUG, "Defaulting to 320x200\n");
                screenWidth = 320;
                screenHeight = 200;
            }
        } else if (!strcmp(result, "--bits")) {
            result = strtok(NULL, " ");
            screenBits = atoi(result);
            switch (screenBits) {
                case 8:
                case 16:
                case 24:
                case 32:
                    break;
                default:
                    dbglog(DBG_DEBUG, "Screen bits must be either 8, 16, 24 or 32\n");
                    dbglog(DBG_DEBUG, "Defaulting to 8\n");
                    screenBits = 8;
                    break;
            }
            result = strtok(NULL, " ");
            param_samplerate = atoi(result);
            sampleRateGiven = true;
        } else if (!strcmp(result, "--samplerate")) {
            result = strtok(NULL, " ");
            param_samplerate = atoi(result);
            sampleRateGiven = true;
        } else if (!strcmp(result, "--audiobuffer")) {
            result = strtok(NULL, " ");
            param_audiobuffer = atoi(result);
            audioBufferGiven = true;
        } else if (!strcmp(result, "--goodtimes"))
            param_goodtimes = true;

        result = strtok(NULL, " ");
    }

    free(buf);

    if (sampleRateGiven && !audioBufferGiven)
        param_audiobuffer = 4096 / (44100 / param_samplerate);
}

void DC_LoadMaps() {
    fs_chdir("/cd/data/wolf4sdldc_cmp");

#ifdef SPEAR
#ifndef SPEARDEMO
    fs_copy("audiohed.sod", "/ram/audiohed.sod");
    fs_copy("audiot.sod", "/ram/audiot.sod");
    fs_copy("vgadict.sod", "/ram/vgadict.sod");
    fs_copy("vgagraph.sod", "/ram/vgagraph.sod");
    fs_copy("vgahead.sod", "/ram/vgahead.sod");
    switch(param_mission) {
        case 1:
            fs_copy("gamemaps.sod", "/ram/gamemaps.sod");
            fs_copy("maphead.sod", "/ram/maphead.sod");
            fs_copy("vswap.sod", "/ram/vswap.sod");
            break;
        case 2:
            fs_copy("gamemaps.sd2", "/ram/gamemaps.sd2");
            fs_copy("maphead.sd2", "/ram/maphead.sd2");
            fs_copy("vswap.sd2", "/ram/vswap.sd2");
            break;
        case 3:
            fs_copy("gamemaps.sd3", "/ram/gamemaps.sd3");
            fs_copy("maphead.sd3", "/ram/maphead.sd3");
            fs_copy("vswap.sd3", "/ram/vswap.sd3");
            break;
    }
#else
    fs_copy("audiohed.sdm", "/ram/audiohed.sdm");
    fs_copy("audiot.sdm", "/ram/audiot.sdm");
    fs_copy("vgadict.sdm", "/ram/vgadict.sdm");
    fs_copy("vgagraph.sdm", "/ram/vgagraph.sdm");
    fs_copy("vgahead.sdm", "/ram/vgahead.sdm");
    fs_copy("gamemaps.sdm", "/ram/gamemaps.sdm");
    fs_copy("maphead.sdm", "/ram/maphead.sdm");
    fs_copy("vswap.sdm", "/ram/vswap.sdm");
#endif
#else
#ifndef UPLOAD
    fs_copy("audiohed.wl6", "/ram/audiohed.wl6");
    fs_copy("audiot.wl6", "/ram/audiot.wl6");
    fs_copy("vgadict.wl6", "/ram/vgadict.wl6");
    fs_copy("vgagraph.wl6", "/ram/vgagraph.wl6");
    fs_copy("vgahead.wl6", "/ram/vgahead.wl6");
    fs_copy("gamemaps.wl6", "/ram/gamemaps.wl6");
    fs_copy("maphead.wl6", "/ram/maphead.wl6");
    fs_copy("vswap.wl6", "/ram/vswap.wl6");
#else
    fs_copy("audiohed.wl1", "/ram/audiohed.wl1");
    fs_copy("audiot.wl1", "/ram/audiot.wl1");
    fs_copy("vgadict.wl1", "/ram/vgadict.wl1");
    fs_copy("vgagraph.wl1", "/ram/vgagraph.wl1");
    fs_copy("vgahead.wl1", "/ram/vgahead.wl1");
    fs_copy("gamemaps.wl1", "/ram/gamemaps.wl1");
    fs_copy("maphead.wl1", "/ram/maphead.wl1");
    fs_copy("vswap.wl1", "/ram/vswap.wl1");
#endif
#endif

    fs_chdir("/ram");
}


void DC_Init() {
    DC_CheckArguments();
    DC_LoadMaps();
}

#endif
